globals [
  totannual-wdischarge ; daily water discharge (m3/sec) in one year     
  normaldischarge      ; water discharge (m3/sec) in one day
  wdischarge           ; actual water discharge (m3/day) in one day
  wdemand              ; water demand
  seqwdemand           ; water demand
  seqminwdemand        ; water demand used in the optimized sequential scenario
  max-wdemand          ; maximum water demand
  min-wdemand          ; minimum water demand
  wdemand-s3           ; water demand during stage 3 of the irrigation season
  max-wdemand-s3       ; maximum water demand during stage 3 of the irrigation season
  min-wdemand-s3       ; minimum water demand during stage 3 of the irrigation season
  seqwdemand-s3        ; water demand usend in the sequentials scenarios during stage 3 of the irrigation season
  clength              ; distance to water source
  wuse                 ; water used per time (m3/s) to irrigate a section 
  eva                  ; evapotranspiration/leakage/seepage (m2/s)  
  ava-wdischarge       ; wdischarge available for each sector
  current-demand       ; water demand
  totyield             ; total yield of six irrigation sectors
  alpha                ; parameter of the yield function
  beta                 ; parameter of the yield function
]
turtles-own [
  area                 ; area of the sections (m2)
  wheight              ; water height (mm)
  old-wheight
  satisfied?           ; satisfied sectors
  diswater             ; distance to water source (m)
  wneed                ; water need each time step
  wused                ; amount of water used per time (m3/s)
  myflow               ; water flow through the gates
  wstress              ; water stress
  cumwstress           ; cumulative water stress
  yield                ; yield of each sector
  irrigation-turn      ; turn to irrigate in the 12-hour and 24-hour policy
  myWaterloss          ; water loss of each sector, varies with the canal length
  usedflow             ; water flow used by each irrigation sector
  z
] 

links-own [
  flow                 ; water discharge (m3/s)
]

to setup
  ca
  set eva 0.02 
  set ava-wdischarge 0
  import-data
  setup-sectors
  setup-canals
  define-irrigation-turn
  update-outputs
end

to setup-sectors
  set-default-shape turtles "square"
  crt 6 [
    set color white
    set label who + 1
    set area 11.67 * 10000 ; m2 ;; all the sectors have the same area
    ifelse scenario = "Shock" [set wheight 50 set old-wheight 50] [ set wheight 0 set old-wheight 0] ; in the stage 3 of the irrigation, the starting water height is 50
    set wused 0
    set myflow 0
    set cumwstress 0
    set yield 0
    set myWaterloss 0
    set satisfied? false   
    set yield 0
    
    ifelse policy = "Open Flow"[  
      ask turtle 0 [ setxy min-pxcor + 1 0 set diswater 366.667]
      ask turtle 1 [ setxy min-pxcor + 3 0 set diswater 211.667]
      ask turtle 2 [ setxy min-pxcor + 5 0 set diswater 711.6667]
      ask turtle 3 [ setxy min-pxcor + 7 0 set diswater 211.6667]
      ask turtle 4 [ setxy min-pxcor + 9 0 set diswater 536.6667]
      ask turtle 5 [ setxy min-pxcor + 11 0 set diswater 711.6667]
    ]
    [
      ask turtle 0 [ setxy min-pxcor + 1 0 set diswater 950 ]
      ask turtle 1 [ setxy min-pxcor + 3 0 set diswater 950 ]
      ask turtle 2 [ setxy min-pxcor + 5 0 set diswater 1450 ]
      ask turtle 3 [ setxy min-pxcor + 7 0 set diswater 950 ]
      ask turtle 4 [ setxy min-pxcor + 9 0 set diswater 1200 ]
      ask turtle 5 [ setxy min-pxcor + 11 0 set diswater 1450 ]
    ]  
    ifelse scenario = "Physical infrastructure" [set myWaterloss diswater * 0.01 * Water-loss * 0.001 * 24 * 3600] [set myWaterloss 0] ; water loss in m3/day/100 m
    if scenario = "Shock" [set myWaterloss 0.003 * diswater * 0.01 *  24 * 3600] 
  ]
  
end

to setup-canals
  ask turtle 0 [ create-link-with turtle 1 ]
  ask turtle 1 [ create-link-with turtle 2 ]
  ask turtle 2 [ create-link-with turtle 3 ]
  ask turtle 3 [ create-link-with turtle 4 ]
  ask turtle 4 [ create-link-with turtle 5 ]
  
  ask links [
    set flow 0
    set thickness  0.1
    set color gray
  ]
end

to go
  tick
  if ticks = 21 [ stop ]
  calculate-wdischarge  
  evaporate
  irrigate
  calculate-wstress
  calculate-yield
  ;; update views   
  if view = "Water depth" [ask turtles [set color scale-color blue wheight 300 30]]
  if view = "% Yield" [ask turtles [set color scale-color green yield 1.5 0]]
  update-outputs
end

to calculate-wdischarge
  ;; Define Scenario
  ifelse scenario = "Shock" [set normaldischarge (item (ticks + 60) totannual-wdischarge * 0.1 * 24 * 3600 ) ] [set normaldischarge (item ticks totannual-wdischarge * 0.1 * 24 * 3600) ]
  
  if scenario = "Nominal flow" or scenario = "Physical infrastructure"[ set wdischarge normaldischarge - normaldischarge * Discharge-reduction ]
  
  if scenario = "Temporal shifts" [
    ifelse ticks <= Shift [set wdischarge (item (((length totannual-wdischarge) - 1) - Shift + ticks) totannual-wdischarge) * 0.1 * 24 * 3600]
    [set wdischarge (item (ticks - Shift) totannual-wdischarge) * 0.1 * 24 * 3600]
  ]
  
  if scenario = "Shock" [ 
    ifelse ticks >= Time-repair [
      ; after the necessary time to repair the cannal (5 or 8 days) is reached, flow increases steadily and by the 20th day, the canal flow is restored to the nominal flow capacity (0.6)
      let w-timerepair5 [0.00 0.04 0.08 0.12 0.16 0.20 0.24 0.28 0.32 0.36 0.40 0.44 0.48 0.52 0.56 0.60] 
      let w-timerepair8 [0.00 0.05 0.10 0.15 0.20 0.25 0.30 0.35 0.40 0.45 0.50 0.55 0.60] 
      if Time-repair = 5 [
        set wdischarge item (ticks - Time-repair) w-timerepair5 
        set wdischarge wdischarge * 3600 * 24
      ]
      if Time-repair = 8 [
        set wdischarge item (ticks - Time-repair) w-timerepair8 
        set wdischarge wdischarge * 3600 * 24
      ]     
    ]
    [ set wdischarge 0 ]
  ]
end

to evaporate
  
  ;; Define Policies
  ifelse scenario = "Shock" 
    [
      if policy = "Optimized sequential" [set current-demand item ticks seqwdemand-s3] 
      if policy = "Sequential" or policy = "24 Hour rotation"  or policy = "12 Hour rotation" [set current-demand item ticks seqwdemand-s3]
      if policy = "Open Flow" [set current-demand item ticks wdemand-s3] 
    ]
    [
      if policy = "Optimized sequential" [set current-demand item ticks seqminwdemand] 
      if policy = "Sequential" or policy = "24 Hour rotation"  or policy = "12 Hour rotation" [set current-demand item ticks seqwdemand]
      if policy = "Open Flow" [set current-demand item ticks wdemand] 
    ]
  
  ask turtles [
    set old-wheight wheight
    if old-wheight >= current-demand [set wneed 0]
    set wneed 0
    set wneed wneed + current-demand - old-wheight 
    if wneed < 0 [set wneed 0]
    set wheight wheight - wheight * eva
    if wheight < 0 [set wheight 0]
  ]  
end


to irrigate
 
  if policy = "Open Flow" [
    ask turtles [
      set ava-wdischarge wdischarge / 6
      set ava-wdischarge ava-wdischarge - myWaterloss
      if ava-wdischarge < 0 [set ava-wdischarge 0]   
      set myflow ava-wdischarge
      set old-wheight wheight
      set wheight old-wheight + myflow / area * 1000 
      if wheight > current-demand [set wheight current-demand ] 
      set usedflow (wheight - old-wheight) * area / 1000 
      if usedflow < 0 [set usedflow 0]
      set ava-wdischarge ava-wdischarge - usedflow
      if ava-wdischarge < 0 [set ava-wdischarge 0]
    ]
  ]
  
  
  ;;24 and 12 hour rotation policy
  if policy = "24 Hour rotation"  or policy = "12 Hour rotation" [ 
    foreach [0 1 2 3 4 5] [ 
      ask turtles with [who = ?] [
        ifelse (item ticks irrigation-turn) = 1 [
          ifelse policy = "12 Hour rotation" [set ava-wdischarge wdischarge / 2] [set ava-wdischarge wdischarge]
          set ava-wdischarge ava-wdischarge - myWaterloss 
          if ava-wdischarge < 0 [set ava-wdischarge 0]   
          set myflow ava-wdischarge
          ifelse wneed > 0 [
            set wheight old-wheight + myflow / area * 1000
            if wheight > current-demand [set wheight current-demand ]         
            ifelse wheight > old-wheight [set usedflow (wheight - old-wheight) * area / 1000 ] [set usedflow 0]
            if usedflow < 0 [set usedflow 0]
            set ava-wdischarge ava-wdischarge - usedflow
            if ava-wdischarge < 0 [set ava-wdischarge 0]  
          ]
          [
            set myflow 0
            set wheight old-wheight + ((myflow ) / area) * 1000
            if wheight > current-demand [set wheight current-demand ]
          ]
        ]
        [
          set myflow 0
          if wheight > current-demand [ set wheight current-demand ] ; water is used. The wheight of the inactive turtles is updated.     
        ]
      ]]
  ]
  
  ;;Sequential and Optimized sequential
  if policy = "Sequential"  or policy = "Optimized sequential" [
    
    foreach [0 1 2 3 4 5] [ 
      ask turtles with [who = ?] [
        
        if policy = "Sequential" [set z 200]
        if policy = "Optimized sequential" [set z 150]
        ifelse who = 0 [
          set ava-wdischarge wdischarge - myWaterloss
          if ava-wdischarge < 0 [set ava-wdischarge 0]   
          ifelse satisfied? = true
            [
              set usedflow 0              
              if wheight > current-demand [set wheight current-demand ]
            ]
            [ 
              set myflow ava-wdischarge 
              set wheight old-wheight + myflow / area * 1000 
              if wheight > current-demand [set wheight current-demand ]
              set usedflow (wheight - old-wheight) * area / 1000              
              if usedflow < 0 [set usedflow 0]
              set ava-wdischarge ava-wdischarge - usedflow
              if ava-wdischarge < 0 [set ava-wdischarge 0]  
            ]
        ]
        [
          ifelse satisfied? = true 
            [
              if wheight > current-demand [set wheight current-demand ]     
            ]
            [
              set myflow ava-wdischarge 
              set wheight old-wheight + myflow / area * 1000 
              if wheight > current-demand [set wheight current-demand ]
              set usedflow (wheight - old-wheight) * area / 1000 
              if usedflow < 0 [set usedflow 0]
              set ava-wdischarge ava-wdischarge - usedflow
              if ava-wdischarge < 0 [set ava-wdischarge 0] 
            ]        
        ]      
        ; once a sector reached wdemand, they don't irrigate. 
        if policy = "Sequential"[
          let x 200 
          if wheight >= x [set satisfied? true]
        ]
        ; once a sector reached the wdemand, they don't irrigate. 
        if policy = "Optimized sequential" [
          let x 150
          if wheight >= x [set satisfied? true]
        ]
      ]
    ]
  ]
end

to calculate-wstress
  ask turtles [
    ifelse scenario = "Shock" [
      set wstress (item ticks min-wdemand-s3) - wheight
      if wstress < 0 [set wstress 0]
      set cumwstress cumwstress + wstress
      if cumwstress < 0 [set cumwstress 0]
    ]
    [
      set wstress (item ticks min-wdemand) - wheight
      if wstress < 0 [set wstress 0]
      set cumwstress cumwstress + wstress
      if cumwstress < 0 [set cumwstress 0]  
    ]
  ]
end


to calculate-yield
  
  ask turtles [      
    ifelse scenario = "Shock" 
      [ set alpha 0.05 set beta 100 ]
      [ set alpha 0.10 set beta 50 ] 
    ;;atan(-alpha*(cumwstress-beta))
    let y (alpha * (cumwstress - beta))  
    if y < 0 [set y 0 - y] ; negative number
    set y (atan y 1 ) * pi / 180
    if (cumwstress > beta) [set y (0 - y)]  ; negative number
    let yo (atan (alpha * beta)  1) * pi / 180  
    set y (y + pi / 2) / (yo + pi / 2)
    set yield y
  ]
  set totyield ([yield] of turtle 0 + [yield] of turtle 1 + [yield] of turtle 2 + [yield] of turtle 3 + [yield] of turtle 4 + [yield] of turtle 5) * 100 / 6
end 
  
to update-outputs
  
  set-current-plot "Water depth"
  set-current-plot-pen "Sector 1" ifelse ticks > 0 [plot [wheight] of turtle 0] [plot 0]
  set-current-plot-pen "Sector 2" ifelse ticks > 0 [plot [wheight] of turtle 1] [plot 0]
  set-current-plot-pen "Sector 3" ifelse ticks > 0 [plot [wheight] of turtle 2] [plot 0]
  set-current-plot-pen "Sector 4" ifelse ticks > 0 [plot [wheight] of turtle 3] [plot 0]
  set-current-plot-pen "Sector 5" ifelse ticks > 0 [plot [wheight] of turtle 4] [plot 0]
  set-current-plot-pen "Sector 6" ifelse ticks > 0 [plot [wheight] of turtle 5] [plot 0]
  ifelse scenario = "Shock" [
    set-current-plot-pen "Maximum" ifelse ticks > 0 [plot item (ticks ) max-wdemand-s3] [plot 0]  
    set-current-plot-pen "Minimum" ifelse ticks > 0 [plot item (ticks ) min-wdemand-s3] [plot 0]   
    set-current-plot-pen "Demand" ifelse ticks > 0 [plot item (ticks ) wdemand-s3] [plot 0]   
  ]
  [
    set-current-plot-pen "Maximum" ifelse ticks > 0 [plot item (ticks ) max-wdemand] [plot 0]  
    set-current-plot-pen "Minimum" ifelse ticks > 0 [plot item (ticks ) min-wdemand] [plot 0]   
    set-current-plot-pen "Demand" ifelse ticks > 0 [plot item (ticks) wdemand] [plot 0]   
  ]
  set-current-plot "% Yield"
  set-current-plot-pen "Sector 1" ifelse ticks > 0 [plot [yield * 100] of turtle 0] [plot 0]
  set-current-plot-pen "Sector 2" ifelse ticks > 0 [plot [yield * 100] of turtle 1] [plot 0]
  set-current-plot-pen "Sector 3" ifelse ticks > 0 [plot [yield * 100] of turtle 2] [plot 0]
  set-current-plot-pen "Sector 4" ifelse ticks > 0 [plot [yield * 100] of turtle 3] [plot 0]
  set-current-plot-pen "Sector 5" ifelse ticks > 0 [plot [yield * 100] of turtle 4] [plot 0]
  set-current-plot-pen "Sector 6" ifelse ticks > 0 [plot [yield * 100] of turtle 5] [plot 0]
end
  
to define-irrigation-turn
  
  ;;Open Flow
  if policy = "Open Flow" [
    ask turtle 0 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 1 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 2 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 3 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 4 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 5 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
  ]
  
   ;;Policy Sequential
  if policy = "Sequential" or policy = "Optimized sequential" [
    ask turtle 0 [set irrigation-turn [0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 1 [set irrigation-turn [0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 2 [set irrigation-turn [0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 3 [set irrigation-turn [0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 4 [set irrigation-turn [0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]]
    ask turtle 5 [set irrigation-turn [0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0]]
  ]
  
  ;;Policy 24 and 12 Hours rotation
  if policy = "24 Hour rotation" [
    ask turtle 0 [set irrigation-turn [0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0]]
    ask turtle 1 [set irrigation-turn [0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0]]
    ask turtle 2 [set irrigation-turn [0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1]]
    ask turtle 3 [set irrigation-turn [0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0]]
    ask turtle 4 [set irrigation-turn [0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0]]
    ask turtle 5 [set irrigation-turn [0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0]]
  ]
  if policy = "12 Hour rotation" [
    ask turtle 0 [set irrigation-turn [0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0]]
    ask turtle 1 [set irrigation-turn [0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0]]
    ask turtle 2 [set irrigation-turn [0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0]]
    ask turtle 3 [set irrigation-turn [0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0]]
    ask turtle 4 [set irrigation-turn [0 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1]]
    ask turtle 5 [set irrigation-turn [0 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1 0 0 1]]
  ]
end
  
to import-data
  
  ;; Import water demand
  ifelse ( file-exists? "WaterDemand.txt" )
  [
    set wdemand []
    file-open "WaterDemand.txt"
    while [ not file-at-end? ]
    [
      set wdemand sentence wdemand (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no WaterDemand.txt file in current directory!" ]
  
  ;; Import max water demand
  ifelse ( file-exists? "maxWaterDemand.txt" )
  [
    set max-wdemand []
    file-open "maxWaterDemand.txt"
    while [ not file-at-end? ]
    [
      set max-wdemand sentence max-wdemand (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no maxWaterDemand.txt file in current directory!" ]
  
  ;; Import min water demand
  ifelse ( file-exists? "minWaterDemand.txt" )
  [
    set min-wdemand []
    file-open "minWaterDemand.txt"
    while [ not file-at-end? ]
    [
      set min-wdemand sentence min-wdemand (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no minWaterDemand.txt file in current directory!" ]
  
  ;; Import sequential water demand
  ifelse ( file-exists? "seqDemand.txt" )
  [
    set seqwdemand []
    file-open "seqDemand.txt"
    while [ not file-at-end? ]
    [
      set seqwdemand sentence seqwdemand (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no seqDemand.txt file in current directory!" ]
  
    ;; Import sequential min water demand
  ifelse ( file-exists? "seqMinDemand.txt" ) 
  [
    set seqminwdemand []
    file-open "seqMinDemand.txt"
    while [ not file-at-end? ]
    [
      set seqminwdemand sentence seqminwdemand (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no seqMinDemand.txt file in current directory!" ]

    ;; Import sequential min water demand
  ifelse ( file-exists? "totannual-wdischarge.txt" )
  [
    set totannual-wdischarge []
    file-open "totannual-wdischarge.txt"
    while [ not file-at-end? ]
    [
      set totannual-wdischarge sentence totannual-wdischarge (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no totannual-wdischarge.txt file in current directory!" ]
  
  ;; Import water demand stage3
  ifelse ( file-exists? "WaterDemand-s3.txt" )
  [
    set wdemand-s3 []
    file-open "WaterDemand-s3.txt"
    while [ not file-at-end? ]
    [
      set wdemand-s3 sentence wdemand-s3 (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no WaterDemand-s3.txt file in current directory!" ]
  
      ;; Import min water demand stage3
  ifelse ( file-exists? "minWaterDemand-s3.txt" )
  [
    set min-wdemand-s3 []
    file-open "minWaterDemand-s3.txt"
    while [ not file-at-end? ]
    [
      set min-wdemand-s3 sentence min-wdemand-s3 (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no minWaterDemand-s3.txt file in current directory!" ]

  ;; Import max water demand stage3
  ifelse ( file-exists? "maxWaterDemand-s3.txt" )
  [
    set max-wdemand-s3 []
    file-open "maxWaterDemand-s3.txt"
    while [ not file-at-end? ]
    [
      set max-wdemand-s3 sentence max-wdemand-s3 (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no maxWaterDemand-s3.txt file in current directory!" ]
    
  ;; Import sequential water demand stage3
  ifelse ( file-exists? "seqWaterDemand-s3.txt" )
  [
    set seqwdemand-s3 []
    file-open "seqWaterDemand-s3.txt"
    while [ not file-at-end? ]
    [
      set seqwdemand-s3 sentence seqwdemand-s3 (list file-read)
    ]
    file-close
  ]
  [ user-message "There is no seqWaterDemand-s3.txt file in current directory!" ]

end

 
@#$#@#$#@
GRAPHICS-WINDOW
232
25
762
176
6
1
40.0
1
10
1
1
1
0
0
0
1
-6
6
-1
1
1
1
1
ticks

BUTTON
4
10
67
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
70
10
133
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
137
10
200
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

CHOOSER
13
157
188
202
policy
policy
"Open Flow" "Sequential" "Optimized sequential" "12 Hour rotation" "24 Hour rotation"
4

PLOT
209
186
492
363
Water depth
NIL
NIL
0.0
10.0
0.0
300.0
true
true
PENS
"Sector 1" 1.0 0 -13791810 true
"Sector 2" 1.0 0 -6459832 true
"Sector 3" 1.0 0 -8630108 true
"Sector 4" 1.0 0 -955883 true
"Sector 5" 1.0 0 -10899396 true
"Sector 6" 1.0 0 -1184463 true
"Maximum" 1.0 0 -7500403 true
"Minimum" 1.0 0 -7500403 true
"Demand" 1.0 0 -2674135 true

PLOT
498
186
781
363
% Yield
NIL
NIL
0.0
10.0
0.0
100.0
true
true
PENS
"Sector 1" 1.0 0 -13791810 true
"Sector 2" 1.0 0 -6459832 true
"Sector 3" 1.0 0 -8630108 true
"Sector 4" 1.0 0 -955883 true
"Sector 5" 1.0 0 -10899396 true
"Sector 6" 1.0 0 -1184463 true

CHOOSER
13
107
188
152
scenario
scenario
"Nominal flow" "Temporal shifts" "Physical infrastructure" "Shock"
0

SLIDER
15
206
187
239
Discharge-reduction
Discharge-reduction
0
1
0.55
0.01
1
NIL
HORIZONTAL

CHOOSER
32
54
170
99
view
view
"Water depth" "% Yield"
0

SLIDER
15
242
187
275
Water-loss
Water-loss
0
4
0
1
1
NIL
HORIZONTAL

SLIDER
15
278
187
311
Time-repair
Time-repair
0
8
0
1
1
NIL
HORIZONTAL

SLIDER
15
313
187
346
Shift
Shift
0
32
0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This model is a replication of the Pumpa model that simulates the Pumpa Irrigation System in Nepal (Cifdaloz et al. 2010). The purpose of this model is to analyze the robustness of this small-scale irrigation system to two scenarios of disturbances to the natural resource (discharge reduction and time shift in water supply), and  two scenarios of disturbances to the physical infrastructure (canals and gates) using five possible irrigation policies (open flow, sequential rotation, optimized sequential, 24 hour rotation, and 12 hour rotation). 

A full description of the model can be found at http://www.openabm.org/models 


## CREDITS AND REFERENCES

Cifdaloz O, Regmi A, Anderies JM, Rodriguez AA. 2010. Robustness, vulnerability, and adaptive capacity in small-scale social-ecological systems: The Pumpa Irrigation System in Nepal. Ecology and Society 15(3): 39. [online] URL: http://www.ecologyandsociety.org/vol15/iss3/art39/
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="tshift" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[wheight] of turtle 0</metric>
    <metric>[wheight] of turtle 1</metric>
    <metric>[wheight] of turtle 2</metric>
    <metric>[wheight] of turtle 3</metric>
    <metric>[wheight] of turtle 4</metric>
    <metric>[wheight] of turtle 5</metric>
    <metric>[yield * 100] of turtle 0</metric>
    <metric>[yield * 100] of turtle 1</metric>
    <metric>[yield * 100] of turtle 2</metric>
    <metric>[yield * 100] of turtle 3</metric>
    <metric>[yield * 100] of turtle 4</metric>
    <metric>[yield * 100] of turtle 5</metric>
    <metric>totyield</metric>
    <enumeratedValueSet variable="Water-loss">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Discharge-reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;Temporal shifts&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;Open Flow&quot;"/>
      <value value="&quot;Sequential&quot;"/>
      <value value="&quot;Optimized sequential&quot;"/>
      <value value="&quot;24 Hour rotation&quot;"/>
      <value value="&quot;12 Hour rotation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-repair">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Shift" first="0" step="1" last="45"/>
  </experiment>
  <experiment name="disred" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[wheight] of turtle 0</metric>
    <metric>[wheight] of turtle 1</metric>
    <metric>[wheight] of turtle 2</metric>
    <metric>[wheight] of turtle 3</metric>
    <metric>[wheight] of turtle 4</metric>
    <metric>[wheight] of turtle 5</metric>
    <metric>[yield * 100] of turtle 0</metric>
    <metric>[yield * 100] of turtle 1</metric>
    <metric>[yield * 100] of turtle 2</metric>
    <metric>[yield * 100] of turtle 3</metric>
    <metric>[yield * 100] of turtle 4</metric>
    <metric>[yield * 100] of turtle 5</metric>
    <metric>totyield</metric>
    <enumeratedValueSet variable="Water-loss">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Discharge-reduction" first="0" step="0.01" last="1"/>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;Nominal flow&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;Open Flow&quot;"/>
      <value value="&quot;Sequential&quot;"/>
      <value value="&quot;Optimized sequential&quot;"/>
      <value value="&quot;24 Hour rotation&quot;"/>
      <value value="&quot;12 Hour rotation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-repair">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Shift">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shock" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[wheight] of turtle 0</metric>
    <metric>[wheight] of turtle 1</metric>
    <metric>[wheight] of turtle 2</metric>
    <metric>[wheight] of turtle 3</metric>
    <metric>[wheight] of turtle 4</metric>
    <metric>[wheight] of turtle 5</metric>
    <metric>[yield * 100] of turtle 0</metric>
    <metric>[yield * 100] of turtle 1</metric>
    <metric>[yield * 100] of turtle 2</metric>
    <metric>[yield * 100] of turtle 3</metric>
    <metric>[yield * 100] of turtle 4</metric>
    <metric>[yield * 100] of turtle 5</metric>
    <metric>totyield</metric>
    <enumeratedValueSet variable="Water-loss">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Discharge-reduction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;Shock&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;Open Flow&quot;"/>
      <value value="&quot;Sequential&quot;"/>
      <value value="&quot;24 Hour rotation&quot;"/>
      <value value="&quot;12 Hour rotation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-repair">
      <value value="0"/>
      <value value="5"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Shift">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="wloss" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[wheight] of turtle 0</metric>
    <metric>[wheight] of turtle 1</metric>
    <metric>[wheight] of turtle 2</metric>
    <metric>[wheight] of turtle 3</metric>
    <metric>[wheight] of turtle 4</metric>
    <metric>[wheight] of turtle 5</metric>
    <metric>[yield * 100] of turtle 0</metric>
    <metric>[yield * 100] of turtle 1</metric>
    <metric>[yield * 100] of turtle 2</metric>
    <metric>[yield * 100] of turtle 3</metric>
    <metric>[yield * 100] of turtle 4</metric>
    <metric>[yield * 100] of turtle 5</metric>
    <metric>totyield</metric>
    <enumeratedValueSet variable="Water-loss">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Discharge-reduction" first="0" step="0.01" last="1"/>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;Physical infrastructure&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;Open Flow&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-repair">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Shift">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
